@@ -15,20 +15,16 @@
  */
 
 #ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
+
 /**
- * @file globus_ftp_client_data.c Read/Write functions
- *
- * $RCSfile: globus_ftp_client_data.c,v $
- * $Revision: 1.26.10.1 $
- * $Date: 2013/05/07 21:20:04 $
+ * @file globus_ftp_client_data.c
+ * @brief Read/Write functions
  */
-#endif
 
 #include "globus_i_ftp_client.h"
 
 #include <string.h>
 
-#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
  * Data callback information structure.
  *
