@@ -15,14 +15,11 @@
  */
 
 #ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
+
 /**
- * @file globus_ftp_client_debug_plugin.c GridFTP Debugging Plugin Implementation
- *
- * $RCSfile: globus_ftp_client_debug_plugin.c,v $
- * $Revision: 1.21 $
- * $Date: 2011/05/19 04:03:42 $
+ * @file globus_ftp_client_debug_plugin.c
+ * @brief GridFTP Debugging Plugin Implementation
  */
-#endif
 
 #include "globus_ftp_client_debug_plugin.h"
 
@@ -30,7 +27,6 @@
 #include <string.h>
 #include "version.h"
 
-#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /* Module specific macros */
 #define GLOBUS_L_FTP_CLIENT_DEBUG_PLUGIN_NAME "globus_ftp_client_debug_plugin"
 
