@@ -15,23 +15,16 @@
  */
 
 #ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
+
 /**
  * @file globus_ftp_client_restart.c
- * Globus FTP Client Library Restart Support.
- *
- * $RCSfile: globus_ftp_client_restart.c,v $
- * $Revision: 1.16.10.1 $
- * $Date: 2012/06/27 14:49:20 $
+ * @brief Globus FTP Client Library Restart Support.
  */
-#endif
 
 #include "globus_i_ftp_client.h"
 #include <string.h>		/* strstr(), strncmp() */
 #include <ctype.h>		/* isupper() */
 
-
-#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
-
 #define CRLF "\r\n"
 
 /* Module-specific prototypes */
